.. documentation master file, created by
   sphinx-quickstart on Mon Apr  3 15:37:35 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MuonDataLib's documentation!
========================================

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Introduction <intro>
   Developer docs <dev/index>
   loaders
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
